<?php

namespace App\DataFixtures;

use App\Entity\Purchase;
use App\Entity\User;
use App\Entity\WishList;
use App\Entity\Item;
use Doctrine\Bundle\FixturesBundle\Fixture;
use Doctrine\Persistence\ObjectManager;
use Doctrine\Common\DataFixtures\DependentFixtureInterface;

class PurchaseFixtures extends Fixture implements DependentFixtureInterface
{
    public function load(ObjectManager $manager): void
    {
        // Fetch existing users, wishlists, and items from the database
        $users = $manager->getRepository(User::class)->findAll();
        $items = $manager->getRepository(Item::class)->findAll();

        if (empty($users) || empty($items)) {
            throw new \Exception('Ensure users and items exist in the database before running this fixture.');
        }

        $purchasesData = [
            [
                'user' => $users[0],
                'item' => $items[0], // Smartphone
                'url_proof' => 'https://example.com/proof1.jpg',
                'message' => 'Hope you like this gift!',
            ],
            [
                'user' => $users[1],
                'item' => $items[1], // Laptop
                'url_proof' => 'https://example.com/proof2.jpg',
                'message' => 'A little surprise for you!',
            ],
            [
                'user' => $users[3],
                'item' => $items[2], // Wireless Headphones
                'url_proof' => 'https://example.com/proof3.jpg',
                'message' => 'Something special just for you!',
            ],
            [
                'user' => $users[4],
                'item' => $items[3], // Coffee Maker
                'url_proof' => 'https://example.com/proof4.jpg',
                'message' => 'Enjoy your new gadget!',
            ],
            [
                'user' => $users[6],
                'item' => $items[4], // Gaming Chair
                'url_proof' => 'https://example.com/proof5.jpg',
                'message' => 'Hope this makes your day!',
            ],
            [
                'user' => $users[7],
                'item' => $items[5], // Smartwatch
                'url_proof' => 'https://example.com/proof6.jpg',
                'message' => 'A little something for you!',
            ],
            [
                'user' => $users[8],
                'item' => $items[6], // Mechanical Keyboard
                'url_proof' => 'https://example.com/proof7.jpg',
                'message' => 'Enjoy your gift!',
            ],
            [
                'user' => $users[9],
                'item' => $items[7], // E-Reader
                'url_proof' => 'https://example.com/proof8.jpg',
                'message' => 'Something I thought you’d love!',
            ],
            [
                'user' => $users[5],
                'item' => $items[8], // Noise Cancelling Earbuds
                'url_proof' => 'https://example.com/proof9.jpg',
                'message' => 'A special gift for a special person!',
            ],
            [
                'user' => $users[2],
                'item' => $items[9], // Camera Drone
                'url_proof' => 'https://example.com/proof10.jpg',
                'message' => 'Just a small token of appreciation!',
            ],
        ];        

        foreach ($purchasesData as $data) {
            $purchase = new Purchase();
            $purchase->setUser($data['user']);
            $purchase->setItem($data['item']);
            $purchase->setUrlProof($data['url_proof']);
            $purchase->setMessage($data['message']);
            $purchase->setCreatedAt(new \DateTimeImmutable());

            $manager->persist($purchase);
        }

        $manager->flush();
    }

    public function getDependencies(): array
    {
        return [
            UserFixtures::class,
            ItemFixtures::class,
        ];
    }
}
