<?php

namespace App\DataFixtures;

use App\Entity\User;
use App\Entity\WishList;
use Doctrine\Bundle\FixturesBundle\Fixture;
use Doctrine\Persistence\ObjectManager;
use Doctrine\Common\DataFixtures\DependentFixtureInterface;

class WishListFixtures extends Fixture implements DependentFixtureInterface
{
    public function load(ObjectManager $manager): void
    {
        // Retrieve all users
        $users = $manager->getRepository(User::class)->findAll();

        if (empty($users)) {
            throw new \Exception('No users found. Please load UserFixtures first.');
        }

        $wishListsData = [
            [
                'name' => 'John\'s Birthday Wishlist',
                'description' => 'Birthday Wishlist',
                'user' => $users[0],
                'expiration_date' => new \DateTime('+30 days'),
                'is_active' => true,
                'url_view_mode' => 'http://url_view_mode.com/john-birthday',
                'url_edit_mode' => 'http://url_edit_mode.com/john-birthday',
            ],
            [
                'name' => 'Tech Gadgets Wishlist',
                'description' => 'Gadgets Wishlist',
                'user' => $users[1],
                'expiration_date' => new \DateTime('+60 days'),
                'is_active' => true,
                'url_view_mode' => 'http://url_view_mode.com/tech-gadgets',
                'url_edit_mode' => 'http://url_edit_mode.com/tech-gadgets',
            ],
            [
                'name' => 'Home Essentials Wishlist',
                'description' => 'Essentials Wishlist',
                'user' => $users[2],
                'expiration_date' => new \DateTime('+90 days'),
                'is_active' => false,
                'url_view_mode' => 'http://url_view_mode.com/home-essentials',
                'url_edit_mode' => 'http://url_edit_mode.com/home-essentials',
            ],
            [
                'name' => 'Fitness Gear Wishlist',
                'description' => 'Wishlist for workout equipment and gear',
                'user' => $users[3],
                'expiration_date' => new \DateTime('+45 days'),
                'is_active' => true,
                'url_view_mode' => 'http://url_view_mode.com/fitness-gear',
                'url_edit_mode' => 'http://url_edit_mode.com/fitness-gear',
            ],
            [
                'name' => 'Gaming Setup Wishlist',
                'description' => 'High-end gaming accessories and equipment',
                'user' => $users[4],
                'expiration_date' => new \DateTime('+75 days'),
                'is_active' => true,
                'url_view_mode' => 'http://url_view_mode.com/gaming-setup',
                'url_edit_mode' => 'http://url_edit_mode.com/gaming-setup',
            ],
            [
                'name' => 'Travel Essentials Wishlist',
                'description' => 'Must-have travel accessories',
                'user' => $users[5],
                'expiration_date' => new \DateTime('+100 days'),
                'is_active' => false,
                'url_view_mode' => 'http://url_view_mode.com/travel-essentials',
                'url_edit_mode' => 'http://url_edit_mode.com/travel-essentials',
            ],
            [
                'name' => 'Photography Gear Wishlist',
                'description' => 'Cameras, lenses, and accessories',
                'user' => $users[6],
                'expiration_date' => new \DateTime('+120 days'),
                'is_active' => true,
                'url_view_mode' => 'http://url_view_mode.com/photography-gear',
                'url_edit_mode' => 'http://url_edit_mode.com/photography-gear',
            ],
            [
                'name' => 'Books & Stationery Wishlist',
                'description' => 'Books, notebooks, and writing accessories',
                'user' => $users[7],
                'expiration_date' => new \DateTime('+150 days'),
                'is_active' => true,
                'url_view_mode' => 'http://url_view_mode.com/books-stationery',
                'url_edit_mode' => 'http://url_edit_mode.com/books-stationery',
            ],
            [
                'name' => 'Kitchen Appliances Wishlist',
                'description' => 'Modern kitchen gadgets and appliances',
                'user' => $users[8],
                'expiration_date' => new \DateTime('+180 days'),
                'is_active' => false,
                'url_view_mode' => 'http://url_view_mode.com/kitchen-appliances',
                'url_edit_mode' => 'http://url_edit_mode.com/kitchen-appliances',
            ],
            [
                'name' => 'Fashion & Accessories Wishlist',
                'description' => 'Trendy clothes, shoes, and accessories',
                'user' => $users[9],
                'expiration_date' => new \DateTime('+200 days'),
                'is_active' => true,
                'url_view_mode' => 'http://url_view_mode.com/fashion-accessories',
                'url_edit_mode' => 'http://url_edit_mode.com/fashion-accessories',
            ],
        ];        

        foreach ($wishListsData as $wishListData) {
            $wishList = new WishList();
            $wishList->setName($wishListData['name']);
            $wishList->setDescription($wishListData['description']);
            $wishList->setUser($wishListData['user']);
            $wishList->setExpirationDate($wishListData['expiration_date']);
            $wishList->setIsActive($wishListData['is_active']);
            $wishList->setUrlViewMode($wishListData['url_view_mode']);
            $wishList->setUrlEditMode($wishListData['url_edit_mode']);
            $wishList->setCreatedAt(new \DateTimeImmutable());

            $manager->persist($wishList);
        }

        $manager->flush();
    }

    public function getDependencies(): array
    {
        return [
            UserFixtures::class
        ];
    }
}
